@@ -1,21 +1,10 @@
 #' Predictions from \code{mrds} models
 #'
-#' Predict detection probabilities (or effective strip widths) values from a
-#' fitted distance sampling model using either the original data (i.e. "fitted"
-#' values) or using new data.
+#' Predict detection probabilities (or effective strip widths/effective areas of detection) from a fitted distance sampling model using either the original data (i.e. "fitted" values) or using new data.
 #'
-#' The first 4 arguments are the same in each predict function.  The latter 2
-#' are specific to certain functions. The effective strip half-width
-#' (\code{esw}) is the integral of the fitted detection function over
-#' either 0 to W or the specified \code{int.range}.  The predicted
-#' detection probability is the average probability which is simply the
-#' integral divided by the distance range.
+#' The first 4 arguments are the same in each predict function.  The latter 2 are specific to certain functions. For line transects, the effective strip half-width (\code{esw=TRUE}) is the integral of the fitted detection function over either 0 to W or the specified \code{int.range}.  The predicted detection probability is the average probability which is simply the integral divided by the distance range. For point transect models, \code{esw=TRUE} calculates the effective area of detection (commonly referred to as "nu", this is the integral of \code{2/width^2 * rg(r)}.
 #'
-#' Fitted detection probabilities are stored in the \code{model} object and
-#' these are returned unless \code{compute=TRUE} or \code{newdata} is specified.
-#'
-#' \code{compute=TRUE} is used to estimate numerical derivatives for use in
-#' delta method approximations to the variance.
+#' Fitted detection probabilities are stored in the \code{model} object and these are returned unless \code{compute=TRUE} or \code{newdata} is specified. \code{compute=TRUE} is used to estimate numerical derivatives for use in delta method approximations to the variance.
 #'
 #' For \code{method="io.fi"} or \code{method="trial.fi"} if
 #' \code{integrate=FALSE}, \code{predict} returns the value of the conditional
@@ -31,11 +20,7 @@
 #'  values stored in the model object.
 #' @param int.range integration range for variable range analysis; either
 #'  vector or matrix.
-#' @param esw if \code{TRUE}, returns effective strip half-width (or effective
-#'   detection radius for points) integral from 0 to the truncation distance
-#'   (\code{width}) of p(y)dy; otherwise it returns the integral from 0 to
-#'   truncation width of p(y)*pi(y) where pi(y)=1/W for lines and pi(y)=2r/W^2
-#'   for points.
+#' @param esw if \code{TRUE}, returns effective strip half-width (or effective area of detection for point transect models) integral from 0 to the truncation distance (\code{width}) of p(y)dy; otherwise it returns the integral from 0 to truncation width of p(y)*pi(y) where pi(y)=1/W for lines and pi(y)=2r/W^2 for points.
 #' @param integrate for \code{*.fi} methods, see Details below.
 #' @param \dots for S3 consistency
 #' @usage \method{predict}{ds}(object,newdata,compute=FALSE,int.range=NULL,esw=FALSE,...)
@@ -45,13 +30,6 @@
 #'        \method{predict}{trial.fi}(object,newdata,compute=FALSE, int.range=NULL,integrate=FALSE,...)
 #'        \method{predict}{rem}(object,newdata,compute=FALSE,int.range=NULL,...)
 #'        \method{predict}{rem.fi}(object,newdata,compute=FALSE, int.range=NULL,integrate=FALSE,...)
-#' @S3method predict ds
-#' @S3method predict io
-#' @S3method predict io.fi
-#' @S3method predict trial
-#' @S3method predict trial.fi
-#' @S3method predict rem
-#' @S3method predict rem.fi
 #' @return For all but the exceptions below, the value is a list with a single
 #'   element: \tabular{ll}{ \code{fitted} \tab vector of average detection
 #'   probabilities or esw values for each observation in the original data or
@@ -78,6 +56,7 @@
 #' @seealso \code{\link{ddf}}, \code{\link{summary.ds}},
 #'   \code{\link{plot.ds}}
 #' @keywords utility
+#' @export
 # Uses: integratedetfct, integratedetfct.logistic
 predict.ds <- function(object,newdata=NULL,compute=FALSE,int.range=NULL,
                        esw=FALSE,...){
@@ -97,7 +76,6 @@ predict.ds <- function(object,newdata=NULL,compute=FALSE,int.range=NULL,
     fpar <- model$par
     ddfobj <- ltmodel$aux$ddfobj
     ddfobj <- assign.par(ddfobj,fpar)
-    doeachint <- ltmodel$aux$doeachint
 
     # Get integration ranges either from specified argument or from
     # values stored in the model.
@@ -153,12 +131,11 @@ predict.ds <- function(object,newdata=NULL,compute=FALSE,int.range=NULL,
     #   int1=integratedetfct.logistic(x,ltmodel$model$scalemodel,width,
     #                         int.range,theta1,ltmodel$aux$integral.numeric,z)
     # else
-    ddfobj$cgftab <- tablecgf(ddfobj,width=width,standardize=TRUE, point=point)
     int1 <- integratepdf(ddfobj,select=rep(TRUE,nrow(ddfobj$xmat)),width=width,
-                         int.range=int.range,doeachint=doeachint,
+                         int.range=int.range,
                          standardize=TRUE,point=point)
     # int1=integratedetfct(ddfobj,select=rep(TRUE,nrow(ddfobj$xmat)),
-    #           width=width,int.range=int.range,doeachint=doeachint,point=point)
+    #           width=width,int.range=int.range,point=point)
 
     # If the predicted values don't need to be computed, then use the values
     # in the model object (model$fitted) and change to integral (esw) values.
